@@ -9,9 +9,12 @@
 
 #include <jni.h>
 #include <libgnomecanvas/libgnomecanvas.h>
-#include <libgtk-java/jg_jnu.h>
+#include <jg_jnu.h>
+
+#include "org_gnu_gnome_CanvasRect.h"
 
 #ifdef __cplusplus
+
 extern "C" 
 {
 #endif
