@@ -12,12 +12,14 @@
 #include <jg_jnu.h>
 #include <gtk_java.h>
 
+#include "org_gnu_gnome_CanvasWidget.h"
+
 #ifdef __cplusplus
 extern "C" 
 {
 #endif
 
-GtkWidget * GnomeCanvasWidget_get_widget (GnomeCanvasWidget * cptr) 
+static GtkWidget * GnomeCanvasWidget_get_widget (GnomeCanvasWidget * cptr) 
 {
     return cptr->widget;
 }
@@ -33,7 +35,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gnome_CanvasWidget_getWidget (JNIEnv *env
     return getGObjectHandle(env, G_OBJECT(GnomeCanvasWidget_get_widget (cptr_g)));
 }
 
-void GnomeCanvasWidget_set_widget (GnomeCanvasWidget * cptr, GtkWidget * widget) 
+static void GnomeCanvasWidget_set_widget (GnomeCanvasWidget * cptr, GtkWidget * widget) 
 {
     cptr->widget = widget;
 }
@@ -42,7 +44,7 @@ void GnomeCanvasWidget_set_widget (GnomeCanvasWidget * cptr, GtkWidget * widget)
  * Class:     org.gnu.gnome.CanvasWidget
  * Method:    setWidget
  */
-JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasWidget_setWidget (JNIEnv *env, jobject cptr, jobject 
+  JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasWidget_setWidget (JNIEnv *env, jclass cls, jobject cptr, jobject 
     widget) 
 {
     GnomeCanvasWidget *cptr_g = (GnomeCanvasWidget *)getPointerFromHandle(env, cptr);
@@ -50,7 +52,7 @@ JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasWidget_setWidget (JNIEnv *env, j
     GnomeCanvasWidget_set_widget (cptr_g, widget_g);
 }
 
-gdouble GnomeCanvasWidget_get_x (GnomeCanvasWidget * cptr) 
+static gdouble GnomeCanvasWidget_get_x (GnomeCanvasWidget * cptr) 
 {
     return cptr->x;
 }
@@ -66,7 +68,7 @@ JNIEXPORT jdouble JNICALL Java_org_gnu_gnome_CanvasWidget_getX (JNIEnv *env, jcl
     return (jdouble) (GnomeCanvasWidget_get_x (cptr_g));
 }
 
-void GnomeCanvasWidget_set_x (GnomeCanvasWidget * cptr, gdouble x) 
+static void GnomeCanvasWidget_set_x (GnomeCanvasWidget * cptr, gdouble x) 
 {
     cptr->x = x;
 }
@@ -75,14 +77,14 @@ void GnomeCanvasWidget_set_x (GnomeCanvasWidget * cptr, gdouble x)
  * Class:     org.gnu.gnome.CanvasWidget
  * Method:    setX
  */
-JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasWidget_setX (JNIEnv *env, jobject cptr, jdouble x) 
+JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasWidget_setX (JNIEnv *env, jclass cls, jobject cptr, jdouble x) 
 {
     GnomeCanvasWidget *cptr_g = (GnomeCanvasWidget *)getPointerFromHandle(env, cptr);
     gdouble x_g = (gdouble) x;
     GnomeCanvasWidget_set_x (cptr_g, x_g);
 }
 
-gdouble GnomeCanvasWidget_get_y (GnomeCanvasWidget * cptr) 
+static gdouble GnomeCanvasWidget_get_y (GnomeCanvasWidget * cptr) 
 {
     return cptr->y;
 }
@@ -98,7 +100,7 @@ JNIEXPORT jdouble JNICALL Java_org_gnu_gnome_CanvasWidget_getY (JNIEnv *env, jcl
     return (jdouble) (GnomeCanvasWidget_get_y (cptr_g));
 }
 
-void GnomeCanvasWidget_set_y (GnomeCanvasWidget * cptr, gdouble y) 
+static void GnomeCanvasWidget_set_y (GnomeCanvasWidget * cptr, gdouble y) 
 {
     cptr->y = y;
 }
@@ -107,14 +109,14 @@ void GnomeCanvasWidget_set_y (GnomeCanvasWidget * cptr, gdouble y)
  * Class:     org.gnu.gnome.CanvasWidget
  * Method:    setY
  */
-JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasWidget_setY (JNIEnv *env, jobject cptr, jdouble y) 
+JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasWidget_setY (JNIEnv *env, jclass cls, jobject cptr, jdouble y) 
 {
     GnomeCanvasWidget *cptr_g = (GnomeCanvasWidget *)getPointerFromHandle(env, cptr);
     gdouble y_g = (gdouble) y;
     GnomeCanvasWidget_set_y (cptr_g, y_g);
 }
 
-gdouble GnomeCanvasWidget_get_width (GnomeCanvasWidget * cptr) 
+static gdouble GnomeCanvasWidget_get_width (GnomeCanvasWidget * cptr) 
 {
     return cptr->width;
 }
@@ -130,7 +132,7 @@ JNIEXPORT jdouble JNICALL Java_org_gnu_gnome_CanvasWidget_getWidth (JNIEnv *env,
     return (jdouble) (GnomeCanvasWidget_get_width (cptr_g));
 }
 
-void GnomeCanvasWidget_set_width (GnomeCanvasWidget * cptr, gdouble width) 
+static void GnomeCanvasWidget_set_width (GnomeCanvasWidget * cptr, gdouble width) 
 {
     cptr->width = width;
 }
@@ -139,7 +141,7 @@ void GnomeCanvasWidget_set_width (GnomeCanvasWidget * cptr, gdouble width)
  * Class:     org.gnu.gnome.CanvasWidget
  * Method:    setWidth
  */
-JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasWidget_setWidth (JNIEnv *env, jobject cptr, 
+JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasWidget_setWidth (JNIEnv *env, jclass cls, jobject cptr, 
     jdouble width) 
 {
     GnomeCanvasWidget *cptr_g = (GnomeCanvasWidget *)getPointerFromHandle(env, cptr);
@@ -147,7 +149,7 @@ JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasWidget_setWidth (JNIEnv *env, jo
     GnomeCanvasWidget_set_width (cptr_g, width_g);
 }
 
-gdouble GnomeCanvasWidget_get_height (GnomeCanvasWidget * cptr) 
+static gdouble GnomeCanvasWidget_get_height (GnomeCanvasWidget * cptr) 
 {
     return cptr->height;
 }
@@ -163,7 +165,7 @@ JNIEXPORT jdouble JNICALL Java_org_gnu_gnome_CanvasWidget_getHeight (JNIEnv *env
     return (jdouble) (GnomeCanvasWidget_get_height (cptr_g));
 }
 
-void GnomeCanvasWidget_set_height (GnomeCanvasWidget * cptr, gdouble height) 
+static void GnomeCanvasWidget_set_height (GnomeCanvasWidget * cptr, gdouble height) 
 {
     cptr->height = height;
 }
@@ -172,7 +174,7 @@ void GnomeCanvasWidget_set_height (GnomeCanvasWidget * cptr, gdouble height)
  * Class:     org.gnu.gnome.CanvasWidget
  * Method:    setHeight
  */
-JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasWidget_setHeight (JNIEnv *env, jobject cptr, 
+JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasWidget_setHeight (JNIEnv *env, jclass cls, jobject cptr, 
     jdouble height) 
 {
     GnomeCanvasWidget *cptr_g = (GnomeCanvasWidget *)getPointerFromHandle(env, cptr);
@@ -180,7 +182,7 @@ JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasWidget_setHeight (JNIEnv *env, j
     GnomeCanvasWidget_set_height (cptr_g, height_g);
 }
 
-GtkAnchorType GnomeCanvasWidget_get_anchor (GnomeCanvasWidget * cptr) 
+static GtkAnchorType GnomeCanvasWidget_get_anchor (GnomeCanvasWidget * cptr) 
 {
     return cptr->anchor;
 }
@@ -196,7 +198,7 @@ JNIEXPORT jint JNICALL Java_org_gnu_gnome_CanvasWidget_getAnchor (JNIEnv *env, j
     return (jint) (GnomeCanvasWidget_get_anchor (cptr_g));
 }
 
-void GnomeCanvasWidget_set_anchor (GnomeCanvasWidget * cptr, GtkAnchorType anchor) 
+static void GnomeCanvasWidget_set_anchor (GnomeCanvasWidget * cptr, GtkAnchorType anchor) 
 {
     cptr->anchor = anchor;
 }
@@ -205,7 +207,7 @@ void GnomeCanvasWidget_set_anchor (GnomeCanvasWidget * cptr, GtkAnchorType ancho
  * Class:     org.gnu.gnome.CanvasWidget
  * Method:    setAnchor
  */
-JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasWidget_setAnchor (JNIEnv *env, jobject cptr, jint 
+JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasWidget_setAnchor (JNIEnv *env, jclass cls, jobject cptr, jint 
     anchor) 
 {
     GnomeCanvasWidget *cptr_g = (GnomeCanvasWidget *)getPointerFromHandle(env, cptr);
@@ -213,7 +215,7 @@ JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasWidget_setAnchor (JNIEnv *env, j
     GnomeCanvasWidget_set_anchor (cptr_g, anchor_g);
 }
 
-gboolean GnomeCanvasWidget_get_size_pixels (GnomeCanvasWidget * cptr) 
+static gboolean GnomeCanvasWidget_get_size_pixels (GnomeCanvasWidget * cptr) 
 {
     return cptr->size_pixels;
 }
@@ -229,7 +231,7 @@ JNIEXPORT jboolean JNICALL Java_org_gnu_gnome_CanvasWidget_getSizePixels (JNIEnv
     return (jboolean) (GnomeCanvasWidget_get_size_pixels (cptr_g));
 }
 
-void GnomeCanvasWidget_set_size_pixels (GnomeCanvasWidget * cptr, gboolean size_pixels) 
+static void GnomeCanvasWidget_set_size_pixels (GnomeCanvasWidget * cptr, gboolean size_pixels) 
 {
     cptr->size_pixels = size_pixels;
 }
@@ -238,7 +240,7 @@ void GnomeCanvasWidget_set_size_pixels (GnomeCanvasWidget * cptr, gboolean size_
  * Class:     org.gnu.gnome.CanvasWidget
  * Method:    setSizePixels
  */
-JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasWidget_setSizePixels (JNIEnv *env, jobject cptr, 
+JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasWidget_setSizePixels (JNIEnv *env, jclass cls, jobject cptr,
     jboolean size_pixels) 
 {
     GnomeCanvasWidget *cptr_g = (GnomeCanvasWidget *)getPointerFromHandle(env, cptr);
