@@ -9,7 +9,9 @@
 
 #include <jni.h>
 #include <gnome.h>
-#include <libgtk-java/jg_jnu.h>
+#include <jg_jnu.h>
+
+#include "org_gnu_gnome_Scores.h"
 
 #ifdef __cplusplus
 extern "C" 
